Class: InvoicingApi::Invoice
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- InvoicingApi::Invoice
- Defined in:
- lib/pnap_invoicing_api/models/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The invoice amount.
-
#currency ⇒ Object
The currency of the invoice.
-
#due_date ⇒ Object
Date and time when the invoice payment is due.
-
#id ⇒ Object
The unique resource identifier of the Invoice.
-
#number ⇒ Object
A user-friendly reference number assigned to the invoice.
-
#outstanding_amount ⇒ Object
The invoice outstanding amount.
-
#sent_on ⇒ Object
Date and time when the invoice was sent.
-
#status ⇒ Object
The status of the invoice.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Invoice
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Invoice
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `InvoicingApi::Invoice` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `InvoicingApi::Invoice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'outstanding_amount') self.outstanding_amount = attributes[:'outstanding_amount'] else self.outstanding_amount = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'sent_on') self.sent_on = attributes[:'sent_on'] else self.sent_on = nil end if attributes.key?(:'due_date') self.due_date = attributes[:'due_date'] else self.due_date = nil end end |
Instance Attribute Details
#amount ⇒ Object
The invoice amount.
28 29 30 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 28 def amount @amount end |
#currency ⇒ Object
The currency of the invoice. Currently, this field should be set to ‘EUR` or `USD`.
25 26 27 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 25 def currency @currency end |
#due_date ⇒ Object
Date and time when the invoice payment is due.
40 41 42 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 40 def due_date @due_date end |
#id ⇒ Object
The unique resource identifier of the Invoice.
19 20 21 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 19 def id @id end |
#number ⇒ Object
A user-friendly reference number assigned to the invoice.
22 23 24 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 22 def number @number end |
#outstanding_amount ⇒ Object
The invoice outstanding amount.
31 32 33 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 31 def outstanding_amount @outstanding_amount end |
#sent_on ⇒ Object
Date and time when the invoice was sent.
37 38 39 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 37 def sent_on @sent_on end |
#status ⇒ Object
The status of the invoice. Currently, this field should be set to ‘PAID`, `OVERDUE`, `PROCESSING_PAYMENT`, or `UNPAID`.
34 35 36 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 34 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 43 def self.attribute_map { :'id' => :'id', :'number' => :'number', :'currency' => :'currency', :'amount' => :'amount', :'outstanding_amount' => :'outstandingAmount', :'status' => :'status', :'sent_on' => :'sentOn', :'due_date' => :'dueDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 67 def self.openapi_types { :'id' => :'String', :'number' => :'String', :'currency' => :'String', :'amount' => :'Float', :'outstanding_amount' => :'Float', :'status' => :'String', :'sent_on' => :'Time', :'due_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 288 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && number == o.number && currency == o.currency && amount == o.amount && outstanding_amount == o.outstanding_amount && status == o.status && sent_on == o.sent_on && due_date == o.due_date end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 309 def hash [id, number, currency, amount, outstanding_amount, status, sent_on, due_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @number.nil? invalid_properties.push('invalid value for "number", number cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @outstanding_amount.nil? invalid_properties.push('invalid value for "outstanding_amount", outstanding_amount cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @sent_on.nil? invalid_properties.push('invalid value for "sent_on", sent_on cannot be nil.') end if @due_date.nil? invalid_properties.push('invalid value for "due_date", due_date cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/pnap_invoicing_api/models/invoice.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @number.nil? return false if @currency.nil? return false if @amount.nil? return false if @outstanding_amount.nil? return false if @status.nil? return false if @sent_on.nil? return false if @due_date.nil? true end |